Learn R Programming

briskaR (version 0.1.2)

Individuals: Class Individuals

Description

Individuals Class consists of spatio-temporal parameters about exposed populations.

Individual gets coordinates (as SpatialPoints), a date of birth, a life duration, an internal toxic concentration over the time and a toxic threshold (max value of toxic before death).

Each individual in an Individuals object is identified by an ID which is used as index to access attributes in the object.

Arguments

Slots

n

individuals Number

coordinate

individuals coordinates (as SpatialPoints)

xmin

x-axis left value

xmax

x-axis right value

ymin

y-axis bottom value

ymax

y-axis top value

dob

Date of birth (as vector)

life_duration

individuals life duration (as vector)

intern_toxic

individuals intern toxic concentration in time (as matrix)

toxic_threshold

individuals max toxic concentration leading to death (as vector)

mintime

Start simulation time

maxtime

End simulation time

Details

Objects can be created by calling of the allocator new("Individuals", ...), or (preferred) by calling one of the wrapped functions simulateIndividuals or loadIndividuals.

See Also

simulateIndividuals , loadIndividuals