Learn R Programming

briskaR (version 0.1.2)

Individuals plot: Plot method for Individuals-class

Description

Will plot Individuals spatial positions.

Will plot individuals positions and state at a time of the simulation.

Usage

# S4 method for Individuals,ANY
plot(x, y, add = F, ..., plot.legend = TRUE)

# S4 method for Individuals,numeric plot(x, y, add = F, ..., plot.legend = TRUE)

Arguments

x

An Individuals object

y

time of the simulation to display individuals

add

if True the new plot will overlap an already plot image (default False)

...

further graphical parameters (par)

plot.legend

plot legend (default TRUE)

Details

The states correspond to internal concentration of toxic. "Red" cross means that the individual is dead because of toxic exposition. "Green" cross means that the individual is dead by natural death. "Green" to "Red" points give the gradient of toxic concentration before the threshold.

Examples

Run this code
# NOT RUN {
data(maize_65)
plot(maize.individuals)
data(maize_65)
# individuals locations
plot(maize.individuals)
# individuals at time 61
plot(maize.individuals,61)
#individuals at time 61 with the landscape
plot(maize.landscape,maize.individuals,time=61)
# }

Run the code above in your browser using DataLab