|
Package: |
briskaR |
|
Type: |
Package |
|
Version: |
0.1.2 |
|
Date: |
2018-06-05 |
|
License: |
GPL (>=2) |
The briskaR package contains functions and methods for quantifying spatio-temporal variation in contamination risk
around known polygon sources of contaminants, and quantifies the impact of the contaminants on the surrounding population of individuals
which are located in habitat areas and are susceptible to the contaminants.
The package implements an spatio-temporal exposure-hazard model based on (i) tools of stochastic geometry (marked polygon and point processes)
for structuring the landscape and describing the location of exposed individuals,
(ii) a method based on a dispersal kernel describing the dissemination of contaminant particles from polygon sources,
and (iii) an ecotoxicological equation describing how contaminants affect individuals of the exposed population.