Learn R Programming

briskaR (version 0.1.2)

getIndividualsLife: Method to get Individuals Life information

Description

Get individuals toxic concentration over the simulation time and return life states for individuals.

Usage

getIndividualsLife(object, ...)

# S4 method for Individuals getIndividualsLife(object)

Arguments

object

An Individuals object

...

other parameters

Value

a matrix indexed by individual ID in rows and by time in columns.

Details

If intern concentration overtakes the toxic threshold value is "-2", that means the individual is dead because of higher toxic concentration. Otherwise value is "-1" means the individual is dead in natural way. The value "0" means that the individual is not alive yet.

Examples

Run this code
# NOT RUN {
# the fifth first individuals states for each time step
data(maize_65)
life<-getIndividualsLife(maize.individuals)
matplot(1:10,life[1:10,],type='l',col=1:5,xlab="source",ylab="states")
# }

Run the code above in your browser using DataLab