Learn R Programming

briskaR (version 0.1.2)

plot,Landscape,Individuals-method: plot Landscape & Individuals method

Description

Plots using Landscape & Individuals objects.

Usage

# S4 method for Landscape,Individuals
plot(x, y, time = -1, objectT = NULL,
  numind = -1, add = F, ..., plot.legend = TRUE)

Arguments

x

A Landscape object

y

An Individuals object

time

Time selection (default = -1) for Toxic intensity

objectT

ToxicIntensityRaster, 3D array (result of toxicIntensity, default NULL)

numind

an individual ID

add

Boolean to draw hover an another plot

...

default plot parameters (par)

plot.legend

plot legend (default TRUE)

Details

If objectT and numind are informed, the function will draw an individual ecoToxical plot.

If objectT and time are specified, the function will draw the landscape, the individuals states and the toxic intensity at this time of the simulation.

By default this function will draw the landscape and the individuals positions.

Examples

Run this code
# NOT RUN {
data(maize_65)
# plot a landscape and individuals
plot(maize.landscape,maize.individuals)
# plot a landscape and individuals states at time 30
plot(maize.landscape,maize.individuals,time=30)
# Simulate pollen dispersion
tox <- toxicIntensity(maize.landscape,maize.emitted_pollen,1,61)
# plot a landscape, individuals and pollen dispersion of maize_65 data
plot(maize.landscape,maize.individuals,time=30,objectT=tox)
# plot ecotoxicology of individual 1.
ind2<-ecoToxic(maize.landscape,maize.individuals,objectT=tox,maxtime=61)
plot(maize.landscape,ind2,objectT=tox,numind=1)
# }

Run the code above in your browser using DataLab