Learn R Programming

briskaR (version 0.1.2)

plotEcotoxic: Plot internal toxic concentration method

Description

Plot a time series of internal toxic concentration for a given individual.

Usage

plotEcoToxic(objectL, objectI, objectT, numind = 1)

Arguments

objectL

A Landscape object

objectI

An Individuals object

objectT

A ToxicIntensityRaster, a 3d array of Toxic intensity over the time [t,x,y], (first indice is time) see toxicIntensity

numind

An individual ID

Examples

Run this code
# NOT RUN {
data(maize_65)
# Simulate pollen dispersion
tox <- toxicIntensity(maize.landscape,maize.emitted_pollen,1,61)
# plot ecotoxicology of individual 1.
ind2<-ecoToxic(maize.landscape,maize.individuals,objectT=tox,maxtime=61)
plot(maize.landscape,ind2,objectT=tox,numind=1)
# }

Run the code above in your browser using DataLab