Individuals Class consists of spatio-temporal parameters about exposed populations.
Individual gets coordinates (as SpatialPoints), a date of birth, a life duration, an internal toxic concentration over the time and a toxic threshold (max value of toxic before death).
Each individual in an Individuals object is identified by an ID which is used as index to access attributes in the object.
nindividuals Number
coordinateindividuals coordinates (as SpatialPoints)
xminx-axis left value
xmaxx-axis right value
yminy-axis bottom value
ymaxy-axis top value
dobDate of birth (as vector)
life_durationindividuals life duration (as vector)
intern_toxicindividuals intern toxic concentration in time (as matrix)
toxic_thresholdindividuals max toxic concentration leading to death (as vector)
mintimeStart simulation time
maxtimeEnd simulation time
Objects can be created by calling of the allocator new("Individuals", ...), or (preferred) by calling one of the wrapped functions simulateIndividuals or loadIndividuals.